@@ -1,6 +1,4 @@
 /*
- * $Id: bogons.c 19266 2011-06-15 16:02:31Z rmanfredi $
- *
  * Copyright (c) 2004, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "common.h"
 
-RCSID("$Id: bogons.c 19266 2011-06-15 16:02:31Z rmanfredi $")
-
 #include "bogons.h"
 #include "settings.h"
 
@@ -70,7 +66,7 @@ static time_t bogons_mtime;			 /**< Modification time of loaded file */
  *
  * @returns the amount of entries loaded.
  */
-static int
+static G_GNUC_COLD int
 bogons_load(FILE *f)
 {
 	char line[1024];
@@ -178,29 +174,32 @@ bogons_changed(const char *filename, gpointer unused_udata)
  * The selected file will then be monitored and a reloading will occur
  * shortly after a modification.
  */
-static void
+static G_GNUC_COLD void
 bogons_retrieve(void)
 {
 	FILE *f;
 	int idx;
 	char *filename;
+	file_path_t fp[4];
+	unsigned length = 0;	
+	char *tmp;
+
+	file_path_set(&fp[length++], settings_config_dir(), bogons_file);
+	tmp = get_folder_path(PRIVLIB_PATH, NULL);
+	if (tmp != NULL)
+		file_path_set(&fp[length++], tmp, bogons_file);
+	
+	file_path_set(&fp[length++], PRIVLIB_EXP, bogons_file);
 #ifndef OFFICIAL_BUILD
-	static file_path_t fp[3];
-#else
-	static file_path_t fp[2];
+	file_path_set(&fp[length++], PACKAGE_EXTRA_SOURCE_DIR, bogons_file);
 #endif
 
-	file_path_set(&fp[0], settings_config_dir(), bogons_file);
-	file_path_set(&fp[1], PRIVLIB_EXP, bogons_file);
-#ifndef OFFICIAL_BUILD
-	file_path_set(&fp[2], PACKAGE_EXTRA_SOURCE_DIR, bogons_file);
-#endif
+	g_assert(length <= G_N_ELEMENTS(fp));
 
-	f = file_config_open_read_norename_chosen(
-			bogons_what, fp, G_N_ELEMENTS(fp), &idx);
+	f = file_config_open_read_norename_chosen(bogons_what, fp, length, &idx);
 
-	if (!f)
-	   return;
+	if (NULL == f)
+	   goto done;
 
 	filename = make_pathname(fp[idx].dir, fp[idx].name);
 	watcher_register(filename, bogons_changed, NULL);
@@ -208,6 +207,9 @@ bogons_retrieve(void)
 
 	bogons_load(f);
 	fclose(f);
+
+done:
+	HFREE_NULL(tmp);
 }
 
 /**
