@@ -1,6 +1,4 @@
 /*
- * $Id: dmesh.c 19325 2011-07-07 12:48:24Z rmanfredi $
- *
  * Copyright (c) 2002-2010, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "common.h"
 
-RCSID("$Id: dmesh.c 19325 2011-07-07 12:48:24Z rmanfredi $")
-
 #include "gtk-gnutella.h"
 
 #include "gnutella.h"
@@ -198,7 +194,7 @@ urlinfo_eq(gconstpointer a, gconstpointer b)
 /**
  * Initialize the download mesh.
  */
-void
+G_GNUC_COLD void
 dmesh_init(void)
 {
 	mesh = g_hash_table_new(sha1_hash, sha1_eq);
@@ -2269,7 +2265,7 @@ dmesh_alternate_location(const struct sha1 *sha1,
 
 	if (can_share_partials && GNET_PROPERTY(is_firewalled)) {
 		size_t url_len;
-		guid_t *servent_guid;
+		guid_t servent_guid;
 
 		gnet_prop_get_storage(PROP_SERVENT_GUID,
 			&servent_guid, sizeof servent_guid);
@@ -2281,7 +2277,7 @@ dmesh_alternate_location(const struct sha1 *sha1,
 		 */
 
 		url_len = dmesh_fwalt_string(url, sizeof url,
-			servent_guid, ipv4_unspecified, 0, NULL);
+			&servent_guid, ipv4_unspecified, 0, NULL);
 
 		g_assert(url_len < sizeof url);
 
@@ -3147,7 +3143,7 @@ dmesh_store(void)
  * Retrieve download mesh and add entries that have not expired yet.
  * The mesh is normally retrieved from ~/.gtk-gnutella/dmesh.
  */
-static void
+static G_GNUC_COLD void
 dmesh_retrieve(void)
 {
 	FILE *f;
@@ -3267,7 +3263,7 @@ dmesh_ban_store(void)
  * Retrieve banned mesh and add entries that have not expired yet.
  * The mesh is normally retrieved from ~/.gtk-gnutella/dmesh_ban.
  */
-static void
+static G_GNUC_COLD void
 dmesh_ban_retrieve(void)
 {
 	FILE *in;
@@ -3357,7 +3353,7 @@ dmesh_ban_prepend_list(gpointer key, gpointer value, gpointer user)
 /**
  * Called at servent shutdown time.
  */
-void
+G_GNUC_COLD void
 dmesh_close(void)
 {
 	GSList *banned = NULL;
