@@ -1,7 +1,5 @@
 /*
- * $Id: dmesh.h 10833 2006-05-09 05:52:45Z cbiere $
- *
- * Copyright (c) 2002-2003, Raphael Manfredi
+ * Copyright (c) 2002-2009, Raphael Manfredi
  *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
@@ -30,19 +28,25 @@
  * Download mesh.
  *
  * @author Raphael Manfredi
- * @date 2002-2003
+ * @date 2002-2009
  */
 
 #ifndef _core_dmesh_h_
 #define _core_dmesh_h_
 
+#include "common.h"
 #include "downloads.h"
 
-#include <glib.h>
-#include <errno.h>
+#include "lib/hashlist.h"
 
 /**
- * A download mesh info (describes an URL).
+ * Our level of support for firewalled alt-locs.
+ */
+#define FWALT_VERSION_MAJOR 0
+#define FWALT_VERSION_MINOR 1
+
+/**
+ * A download mesh info (describes an URL) for a non-firewalled servent.
  *
  * It can describe URLs like:
  *
@@ -53,12 +57,20 @@
  * it's an URN.
  */
 typedef struct {
-	const gchar *name;			/**< File name (atom) */
-	guint idx;					/**< File index (URN_INDEX means URN access) */
+	const char *name;			/**< File name (atom) */
 	host_addr_t addr;			/**< Host address */
+	guint idx;					/**< File index (URN_INDEX means URN access) */
 	guint16 port;				/**< Host port */
 } dmesh_urlinfo_t;
 
+/**
+ * A download mesh info for a firewalled servent.
+ */
+typedef struct {
+	const guid_t *guid;			/**< Servent's GUID (atom) */
+	hash_list_t *proxies;		/**< Known push proxies (gnet_host_t) */
+} dmesh_fwinfo_t;
+
 /**
  * Error codes from dmesh_url_parse().
  */
@@ -82,31 +94,54 @@ extern dmesh_url_error_t dmesh_url_errno;
 void dmesh_init(void);
 void dmesh_close(void);
 
-const gchar *dmesh_url_strerror(dmesh_url_error_t errnum);
-gboolean dmesh_url_parse(const gchar *url, dmesh_urlinfo_t *info);
+gboolean dmesh_can_use_fwalt(void);
+
+const char *dmesh_url_strerror(dmesh_url_error_t errnum);
+gboolean dmesh_url_parse(const char *url, dmesh_urlinfo_t *info);
 
 gboolean dmesh_add(
-	gchar *sha1, const host_addr_t addr, guint16 port, guint idx,
-	const gchar *name, time_t stamp);
+	const struct sha1 *sha1, const host_addr_t addr, guint16 port, guint idx,
+	const char *name, time_t stamp);
 
 gboolean dmesh_remove(
-	const gchar *sha1, const host_addr_t addr, guint16 port, guint idx,
-	const gchar *name);
+	const struct sha1 *sha1, const host_addr_t addr, guint16 port, guint idx,
+	const char *name);
 
-gint dmesh_count(const gchar *sha1);
+void dmesh_add_alternate(const struct sha1 *sha1,
+		host_addr_t addr, guint16 port);
+void dmesh_add_good_alternate(const struct sha1 *sha1,
+		host_addr_t addr, guint16 port);
+void dmesh_remove_alternate(const struct sha1 *sha1,
+		host_addr_t addr, guint16 port);
+void dmesh_add_alternates(const struct sha1 *sha1, const gnet_host_vec_t *vec);
 
-gboolean dmesh_collect_sha1(const gchar *value, gchar *digest);
-void dmesh_collect_locations(const gchar *sha1, gchar *value, gboolean defer);
-void dmesh_collect_compact_locations(const gchar *sha1, const gchar *value);
-gint dmesh_fill_alternate(const gchar *sha1, gnet_host_t *hvec, gint hcnt);
+void dmesh_add_good_firewalled(const struct sha1 *sha1,
+	const struct guid *guid);
 
-gint dmesh_alternate_location(
-	const gchar *sha1, gchar * buf, size_t size, const host_addr_t addr,
-	time_t last_sent, const gchar *vendor, fileinfo_t *fi,
-	gboolean request);
+void dmesh_negative_alt(const struct sha1 *sha1,
+	host_addr_t reporter, host_addr_t addr, guint16 port);
+void dmesh_good_mark(const struct sha1 *sha1,
+	host_addr_t addr, guint16 port, gboolean good);
+
+int dmesh_count(const struct sha1 *sha1);
+
+gboolean dmesh_collect_sha1(const char *value, struct sha1 *sha1);
+void dmesh_collect_locations(const struct sha1 *sha1, const char *value);
+void dmesh_collect_compact_locations(const struct sha1 *sha1,
+		const char *value);
+void dmesh_collect_fw_hosts(const struct sha1 *sha1, const char *value);
+void dmesh_collect_negative_locations(const struct sha1 *sha1,
+	const char *value, host_addr_t reporter);
+int dmesh_fill_alternate(const struct sha1 *sha1,
+		gnet_host_t *hvec, int hcnt);
+
+int dmesh_alternate_location(
+	const struct sha1 *sha1, char * buf, size_t size, const host_addr_t addr,
+	time_t last_sent, const char *vendor, fileinfo_t *fi,
+	gboolean request, const struct guid *guid);
 
 void dmesh_multiple_downloads(
-	const gchar *sha1, filesize_t size, fileinfo_t *fi);
+	const struct sha1 *sha1, filesize_t size, fileinfo_t *fi);
 
 void dmesh_check_results_set(gnet_results_set_t *rs);
 
