@@ -1,6 +1,4 @@
 /*
- * $Id: features.h,v 1.6 2005/06/25 01:37:39 daichik Exp $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -36,36 +34,32 @@
 #ifndef _core_features_h_
 #define _core_features_h_
 
-#include <glib.h>
+#include "common.h"
 
 #include "lib/header.h"		/* For header_t */
 
-struct xfeature_t {
-	GList *features;
-};
+typedef enum {
+	FEATURES_DOWNLOADS,
+	FEATURES_UPLOADS,
+	FEATURES_CONNECTIONS,
 
-typedef struct xfeatures_t {
-	struct xfeature_t uploads;
-	struct xfeature_t downloads;
-	struct xfeature_t connections;
-} xfeatures_t;
+	NUM_FEATURES
+} xfeature_t;
 
 /*
  * Public interface.
  */
 
-extern xfeatures_t xfeatures;
+gboolean header_get_feature(const char *name, const header_t *header,
+		guint *major, guint *minor);
+void header_features_add(xfeature_t xf, const char *name, int major, int minor);
+void header_features_add_guarded(xfeature_t xf, const char *name,
+	int major, int minor, const gboolean *guard);
+void header_features_add_guarded_function(xfeature_t xf,
+	const char *name, int major, int minor, gboolean (*guardfn)(void));
+void header_features_generate(xfeature_t xf, char *buf, size_t len, size_t *rw);
 
-void header_get_feature(const gchar *feature_name, const header_t *header,
-	guint *feature_version_major, guint *feature_version_minor);
-void header_features_add(struct xfeature_t *xfeatures,
-	gchar *feature_name,
-	int feature_version_major,
-	int feature_version_minor);
-void header_features_cleanup(struct xfeature_t *xfeatures);
 void features_close(void);
-void header_features_generate(struct xfeature_t *xfeatures,
-	gchar *buf, size_t len, size_t *rw);
 
 #endif	/* _core_features_h_ */
 
