@@ -1,6 +1,4 @@
 /*
- * $Id: ghc.c 19142 2011-05-23 20:44:04Z rmanfredi $
- *
  * Copyright (c) 2010, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -38,8 +36,6 @@
 
 #include "common.h"
 
-RCSID("$Id: ghc.c 19142 2011-05-23 20:44:04Z rmanfredi $")
-
 #include "ghc.h"
 #include "http.h"
 #include "hcache.h"
@@ -200,6 +196,7 @@ parse_dispatch_lines(gpointer handle, const gchar *buf, size_t len,
 		HFREE_NULL(line);
 
 		if (error) {
+			ghc_ctx.ha = NULL;
 			ghc_connecting = FALSE;
 			return;
 		}
@@ -363,6 +360,7 @@ ghc_host_eof(struct parse_context *ctx)
 			ctx->processed, ctx->processed == 1 ? "" : "s",
 			http_async_info(ghc_ctx.ha, NULL, NULL, NULL, NULL));
 
+	ghc_ctx.ha = NULL;
 	ghc_connecting = FALSE;
 }
 
@@ -383,6 +381,7 @@ ghc_error_ind(struct http_async *handle, http_errtype_t type, gpointer v)
 {
 	http_async_log_error_dbg(handle, type, v, "BOOT GHC",
 		GNET_PROPERTY(bootstrap_debug) > 1);
+	ghc_ctx.ha = NULL;
 	ghc_connecting = FALSE;
 }
 
@@ -444,7 +443,6 @@ ghc_try_random(void)
 
 	if (!ghc_pick()) {
 		ghc_connecting = FALSE;
-		return;
 	}
 }
 
@@ -496,7 +494,7 @@ ghc_is_waiting(void)
 /**
  * Initializations.
  */
-void
+G_GNUC_COLD void
 ghc_init(void)
 {
 	guint i;
@@ -514,7 +512,7 @@ ghc_init(void)
 /**
  * Final cleanup.
  */
-void
+G_GNUC_COLD void
 ghc_close(void)
 {
 	if (ghc_connecting) {
