@@ -1,6 +1,4 @@
 /*
- * $Id: hostiles.c 19286 2011-06-18 20:52:56Z rmanfredi $
- *
  * Copyright (c) 2004-2011, Raphael Manfredi
  * Copyright (c) 2003, Markus Goetz
  *
@@ -40,8 +38,6 @@
 
 #include "common.h"
 
-RCSID("$Id: hostiles.c 19286 2011-06-18 20:52:56Z rmanfredi $")
-
 #include "hostiles.h"
 #include "settings.h"
 #include "nodes.h"
@@ -347,7 +343,7 @@ hostiles_retrieve_from_file(FILE *f, hostiles_t which,
  * The selected file will then be monitored and a reloading will occur
  * shortly after a modification.
  */
-static void
+static G_GNUC_COLD void
 hostiles_retrieve(hostiles_t which)
 {
 	g_assert(UNSIGNED(which) < NUM_HOSTILES);
@@ -374,6 +370,8 @@ hostiles_retrieve(hostiles_t which)
 
 	case HOSTILE_GLOBAL:
 		{
+			/* FIXME: Load also the hostiles from get_folder_path */
+	
 			FILE *f;
 			int idx;
 			static const file_path_t fp[] = {
@@ -911,7 +909,7 @@ hostiles_spam_periodic_sync(void *unused_obj)
 /**
  * Called on startup. Loads the hostiles.txt into memory.
  */
-void
+G_GNUC_COLD void
 hostiles_init(void)
 {
 	dbstore_kv_t kv =
