@@ -1,6 +1,4 @@
 /*
- * $Id: http.c 19180 2011-05-27 19:34:22Z rmanfredi $
- *
  * Copyright (c) 2002-2003, 2010, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -38,8 +36,6 @@
 
 #include "common.h"
 
-RCSID("$Id: http.c 19180 2011-05-27 19:34:22Z rmanfredi $")
-
 #include "nodes.h"
 #include "http.h"
 #include "sockets.h"
@@ -4031,7 +4027,7 @@ http_close(void)
  ***/
 
 #ifdef HTTP_TESTING
-static void
+static G_GNUC_COLD void
 http_transaction_failed(char *data, size_t len, int code, header_t *h, void *a)
 {
 	const char *url = a;
@@ -4047,7 +4043,7 @@ http_transaction_failed(char *data, size_t len, int code, header_t *h, void *a)
 	}
 }
 
-static void
+static G_GNUC_COLD void
 http_transaction_done(char *data, size_t len, int code, header_t *h, void *arg)
 {
 	char *url = arg;
@@ -4077,7 +4073,7 @@ http_transaction_done(char *data, size_t len, int code, header_t *h, void *arg)
 	}
 }
 
-void
+G_GNUC_COLD void
 http_test(void)
 {
 	void *ha;
