@@ -1,6 +1,4 @@
 /*
- * $Id: ipp_cache.c 19142 2011-05-23 20:44:04Z rmanfredi $
- *
  * Copyright (c) 2007-2009, Raphael Manfredi
  * Copyright (c) 2006, Christian Biere
  *
@@ -56,8 +54,6 @@
 
 #include "common.h"
 
-RCSID("$Id: ipp_cache.c 19142 2011-05-23 20:44:04Z rmanfredi $")
-
 #include "lib/bit_array.h"
 #include "lib/file.h"
 #include "lib/getdate.h"
@@ -454,7 +450,7 @@ ipp_cache_remove(enum ipp_cache_id cid, const host_addr_t addr, guint16 port)
 /**
  * Parse persisted cache.
  */
-static void
+static G_GNUC_COLD void
 ipp_cache_parse(ipp_cache_t *ic, FILE *f)
 {
 	bit_array_t tag_used[BIT_ARRAY_SIZE(NUM_IPP_CACHE_TAGS)];
@@ -604,7 +600,7 @@ ipp_cache_clear(ipp_cache_t *ic)
 /**
  * Retrieve cache from disk file.
  */
-static void
+static G_GNUC_COLD void
 ipp_cache_load(ipp_cache_t *ic)
 {
 	FILE *f;
@@ -661,7 +657,7 @@ ipp_cache_invalidate(enum ipp_cache_id cid)
  * structures, as some callbacks may insert data in the caches.  Later on,
  * the caches can be loaded when we know the properties are all initialized.
  */
-void
+G_GNUC_COLD void
 ipp_cache_init(void)
 {
 	caches[IPP_CACHE_TLS] = ipp_cache_alloc(
