@@ -1,6 +1,4 @@
 /*
- * $Id: publisher.c 19142 2011-05-23 20:44:04Z rmanfredi $
- *
  * Copyright (c) 2009, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -42,8 +40,6 @@
 
 #include "common.h"
 
-RCSID("$Id: publisher.c 19142 2011-05-23 20:44:04Z rmanfredi $")
-
 #ifdef I_MATH
 #include <math.h>		/* For log() */
 #endif	/* I_MATH */
@@ -679,7 +675,7 @@ publisher_handle(struct publisher_entry *pe)
 		fileinfo_t *fi = shared_file_fileinfo(sf);
 
 		if (
-			!GNET_PROPERTY(pfsp_server) ||
+			!file_info_partial_shareable(fi) ||
 			fi->done < GNET_PROPERTY(pfsp_minimum_filesize)
 		) {
 			publisher_hold(pe, PUBLISH_BUSY, "PFSP minima not reached");
@@ -919,7 +915,7 @@ publisher_trim_pubdata(void)
 /**
  * Initialize the DHT publisher.
  */
-void
+G_GNUC_COLD void
 publisher_init(void)
 {
 	size_t i;
@@ -1002,7 +998,7 @@ publisher_remove_orphan(gpointer key,
 /**
  * Shutdown the DHT publisher.
  */
-void
+G_GNUC_COLD void
 publisher_close(void)
 {
 	/*
