@@ -1,6 +1,4 @@
 /*
- * $Id: rx_inflate.h 10316 2005-11-26 16:29:07Z cbiere $
- *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -36,6 +34,8 @@
 #ifndef _core_rx_inflate_h_
 #define _core_rx_inflate_h_
 
+#include "common.h"
+
 #include "rx.h"
 
 const struct rxdrv_ops* rx_inflate_get_ops(void);
@@ -44,9 +44,9 @@ const struct rxdrv_ops* rx_inflate_get_ops(void);
  * Callbacks used by the inflating layer.
  */
 struct rx_inflate_cb {
-	void (*add_rx_inflated)(gpointer owner, gint amount);
+	void (*add_rx_inflated)(gpointer owner, int amount);
 	void (*inflate_error)(gpointer owner,
-			const gchar *reason, ...) PRINTF_FUNC_PTR(2, 3);
+			const char *reason, ...) PRINTF_FUNC_PTR(2, 3);
 };
 
 /**
