@@ -1,6 +1,4 @@
 /*
- * $Id: settings.c 19266 2011-06-15 16:02:31Z rmanfredi $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi, Richard Eckart
  *
  *----------------------------------------------------------------------
@@ -96,10 +94,7 @@
 
 #include "lib/override.h"		/* Must be the last header included */
 
-RCSID("$Id: settings.c 19266 2011-06-15 16:02:31Z rmanfredi $")
-
 static const char config_file[] = "config_gnet";
-static const char ul_stats_file[] = "upload_stats";
 
 static const mode_t IPC_DIR_MODE = S_IRUSR | S_IWUSR | S_IXUSR; /* 0700 */
 static const mode_t PID_FILE_MODE = S_IRUSR | S_IWUSR; /* 0600 */
@@ -229,7 +224,7 @@ is_my_address_and_port(const host_addr_t addr, guint16 port)
  *			locked. Other errno values imply that the PID file could not
  *			be created.
  */
-static int
+static G_GNUC_COLD int
 ensure_unicity(const char *file, int *fd_ptr)
 {
 	gboolean locked = FALSE;
@@ -445,7 +440,7 @@ settings_mkdir(const char *path, gboolean fatal)
 /**
  * Initializes "config_dir", "home_dir", "crash_dir", etc...
  */
-void
+G_GNUC_COLD void
 settings_early_init(void)
 {
 	config_dir = h_strdup(getenv("GTK_GNUTELLA_DIR"));
@@ -634,7 +629,7 @@ settings_update_downtime(void)
 	gnet_prop_set_guint32_val(PROP_AVERAGE_SERVENT_DOWNTIME, average);
 }
 
-void
+G_GNUC_COLD void
 settings_init(void)
 {
 	guint64 memory = getphysmemsize();
@@ -720,13 +715,7 @@ settings_init(void)
 		}
 	}
 
-	{
-		char *path;
-
-		path = make_pathname(config_dir, ul_stats_file);
-		upload_stats_load_history(path);	/* Loads the upload statistics */
-		HFREE_NULL(path);
-	}
+	upload_stats_load_history();	/* Loads the upload statistics */
 
 
 	/* watch for filter_file defaults */
@@ -1107,7 +1096,7 @@ settings_max_msg_size(void)
 /**
  * Called at exit time to flush the property files.
  */
-void
+G_GNUC_COLD void
 settings_shutdown(void)
 {
 	update_uptimes();
@@ -2921,7 +2910,7 @@ static prop_map_t property_map[] = {
 
 static gboolean init_list[GNET_PROPERTY_NUM];
 
-static void
+static G_GNUC_COLD void
 settings_callbacks_init(void)
 {
     unsigned n;
