@@ -1,6 +1,4 @@
 /*
- * $Id: share.c 19305 2011-06-24 11:20:28Z rmanfredi $
- *
  * Copyright (c) 2001-2005, Raphael Manfredi
  * Copyright (c) 2000 Daniel Walker (dwalker@cats.ucsc.edu)
  *
@@ -38,8 +36,6 @@
 
 #include "common.h"
 
-RCSID("$Id: share.c 19305 2011-06-24 11:20:28Z rmanfredi $")
-
 #include "share.h"
 #include "extensions.h"
 #include "downloads.h"
@@ -82,6 +78,7 @@ RCSID("$Id: share.c 19305 2011-06-24 11:20:28Z rmanfredi $")
 #include "lib/utf8.h"
 #include "lib/walloc.h"
 
+
 #include "lib/override.h"		/* Must be the last header included */
 
 #define SHARE_RECENT_THRESH		(2 * 7 * 24 * 60 * 60)	/* 2 weeks */
@@ -368,7 +365,7 @@ shared_file_deindex(shared_file_t *sf)
 	}
 	sf->flags &= ~SHARE_F_BASENAME;
 
-	/**
+	/*
 	 * The shared file might not be referenced by the current file_table
 	 * either because it hasn't been build yet or because of a rescan.
 	 */
@@ -394,6 +391,22 @@ shared_file_deindex(shared_file_t *sf)
 	sf->file_index = 0;
 	sf->sort_index = 0;
 	sf->flags &= ~SHARE_F_INDEXED;
+
+	/*
+	 * Shared file is no longer indexed so it no longer belongs to the
+	 * shared set and needs to be removed if it was referenced there.
+	 */
+
+	if (sf->sha1 != NULL) {
+		shared_file_t *current;
+		gpointer key;
+
+		key = deconstify_gpointer(sf->sha1);
+		current = g_tree_lookup(sha1_to_share, key);
+		if (current == sf) {
+			g_tree_remove(sha1_to_share, key);
+		}
+	}
 }
 
 /**
@@ -489,30 +502,32 @@ static const guint SPECIAL_FILE = -3;		/**< Special served files */
  * Initialize special file entry, returning shared_file_t structure if
  * the file exists, NULL otherwise.
  */
-static shared_file_t *
+static G_GNUC_COLD shared_file_t *
 share_special_load(const struct special_file *sp)
 {
 	FILE *f;
-	int idx;
-	shared_file_t *sf;
+	int idx = 0;
+	char *tmp;
+	shared_file_t *sf = NULL;
+	file_path_t fp[4];
+	unsigned length = 0;
 
+	tmp = get_folder_path(PRIVLIB_PATH, NULL);
+	if (tmp != NULL)
+		file_path_set(&fp[length++], tmp, sp->file);
+
+	file_path_set(&fp[length++], settings_config_dir(), sp->file);
+	file_path_set(&fp[length++], PRIVLIB_EXP, sp->file);
 #ifndef OFFICIAL_BUILD
-	file_path_t fp[3];
-#else
-	file_path_t fp[2];
+	file_path_set(&fp[length++], PACKAGE_EXTRA_SOURCE_DIR, sp->file);
 #endif
 
-	file_path_set(&fp[0], settings_config_dir(), sp->file);
-	file_path_set(&fp[1], PRIVLIB_EXP, sp->file);
-#ifndef OFFICIAL_BUILD
-	file_path_set(&fp[2], PACKAGE_EXTRA_SOURCE_DIR, sp->file);
-#endif
+	g_assert(length <= G_N_ELEMENTS(fp));
+	
+	f = file_config_open_read_norename_chosen(sp->what, fp, length, &idx);
 
-	f = file_config_open_read_norename_chosen(
-			sp->what, fp, G_N_ELEMENTS(fp), &idx);
-
-	if (!f)
-		return NULL;
+	if (NULL == f)
+		goto done;
 
 	/*
 	 * Create fake special file sharing structure, so that we can
@@ -535,6 +550,10 @@ share_special_load(const struct special_file *sp)
 	}
 
 	fclose(f);
+
+done:
+	HFREE_NULL(tmp);
+
 	return sf;
 }
 
@@ -574,7 +593,7 @@ shared_files_match(const char *query,
 /**
  * Initialize the special files we're sharing.
  */
-static void
+static G_GNUC_COLD void
 share_special_init(void)
 {
 	guint i;
@@ -2230,7 +2249,7 @@ share_special_close(void)
 /**
  * Shutdown cleanup.
  */
-void
+G_GNUC_COLD void
 share_close(void)
 {
 	recursive_scan_free(&recursive_scan_context);
@@ -2844,7 +2863,7 @@ share_add_partial(const shared_file_t *sf)
 	/*
 	 * We added a new partial file, we need to rebuild the QRP table.
 	 * Do that asynchronously in case we're called frequently from a loop,
-	 * for instane at startup or when many new files are downloaded.
+	 * for instance at startup or when many new files are downloaded.
 	 */
 
 	share_qrp_rebuild_if_needed();
@@ -2888,7 +2907,7 @@ share_update_matching_information(void)
 /**
  * Initialization of the sharing library.
  */
-void
+G_GNUC_COLD void
 share_init(void)
 {
 	size_t i;
