@@ -1,6 +1,4 @@
 /*
- * $Id: spam_sha1.c 19029 2011-05-03 22:02:29Z rmanfredi $
- *
  * Copyright (c) 2007, Christian Biere
  * Copyright (c) 2004, Raphael Manfredi
  * Copyright (c) 2003, Markus Goetz
@@ -41,8 +39,6 @@
 
 #include "common.h"
 
-RCSID("$Id: spam_sha1.c 19029 2011-05-03 22:02:29Z rmanfredi $")
-
 #include "spam.h"
 
 #include "lib/atoms.h"
@@ -87,7 +83,7 @@ struct sha1_lut {
 
 static struct sha1_lut sha1_lut;
 
-static inline int
+static inline G_GNUC_PURE int
 sha1_cmp_func(const void *a, const void *b)
 {
 	return sha1_cmp(a, b);
@@ -189,7 +185,7 @@ spam_sha1_sync(void)
  *
  * @returns the amount of entries loaded or -1 on failure.
  */
-static gulong
+static G_GNUC_COLD gulong
 spam_sha1_load(FILE *f)
 {
 	char line[1024];
@@ -310,24 +306,30 @@ spam_sha1_retrieve_from_file(FILE *f, const char *path, const char *filename)
 static void
 spam_sha1_retrieve(void)
 {
-	static file_path_t fp[3];
-	guint num_fp = G_N_ELEMENTS(fp) - 1;
+	file_path_t fp[4];
 	FILE *f;
 	int idx;
-	
-	file_path_set(&fp[0], settings_config_dir(), spam_sha1_file);
-	file_path_set(&fp[1], PRIVLIB_EXP, spam_sha1_file);
+	char *tmp;
+	unsigned length = 0;
+
+	file_path_set(&fp[length++], settings_config_dir(), spam_sha1_file);
+	file_path_set(&fp[length++], PRIVLIB_EXP, spam_sha1_file);
 
 #ifndef OFFICIAL_BUILD
-	file_path_set(&fp[2], PACKAGE_EXTRA_SOURCE_DIR, spam_sha1_file);
-	num_fp++;
+	file_path_set(&fp[length++], PACKAGE_EXTRA_SOURCE_DIR, spam_sha1_file);
 #endif	/* !OFFICIAL_BUILD */
 
-	f = file_config_open_read_norename_chosen(spam_sha1_what, fp, num_fp, &idx);
-	if (f) {
+	tmp = get_folder_path(PRIVLIB_PATH, NULL);
+	if (tmp != NULL)
+		file_path_set(&fp[length++], tmp, spam_sha1_file);
+
+	f = file_config_open_read_norename_chosen(spam_sha1_what, fp, length, &idx);
+	if (f != NULL) {
 		spam_sha1_retrieve_from_file(f, fp[idx].dir, fp[idx].name);
 		fclose(f);
 	}
+
+	HFREE_NULL(tmp);
 }
 
 /**
