@@ -1,6 +1,4 @@
 /*
- * $Id: uhc.h,v 1.2 2005/06/25 01:37:41 daichik Exp $
- *
  * Copyright (c) 2004, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -36,6 +34,8 @@
 #ifndef _core_uhc_h_
 #define _core_uhc_h_
 
+#include "common.h"
+
 /*
  * Public interface.
  */
@@ -49,7 +49,7 @@ void uhc_get_hosts(void);
 gboolean uhc_is_waiting(void);
 
 void uhc_ipp_extract(
-	struct gnutella_node *n, const gchar *payload, gint paylen);
+	struct gnutella_node *n, const char *payload, int paylen);
 
 #endif /* _core_uhc_h_ */
 
