@@ -1,6 +1,4 @@
 /*
- * $Id: whitelist.c 19329 2011-07-13 19:09:47Z rmanfredi $
- *
  * Copyright (c) 2009, Raphael Manfredi
  * Copyright (c) 2002, Vidar Madsen
  *
@@ -41,8 +39,6 @@
 
 #include "common.h"
 
-RCSID("$Id: whitelist.c 19329 2011-07-13 19:09:47Z rmanfredi $")
-
 #include "whitelist.h"
 #include "settings.h"
 #include "ipp_cache.h"
@@ -321,7 +317,7 @@ whitelist_dns_resolve(struct whitelist *item, gboolean revalidate)
 /**
  * Loads the whitelist into memory.
  */
-static void
+static G_GNUC_COLD void
 whitelist_retrieve(void)
 {
     char line[1024];
@@ -645,7 +641,7 @@ whitelist_periodic_dns(gpointer unused_obj)
  * Ensure we will monitor the file to reloead the whitelist soon after
  * the file is modified (or created if missing initially).
  */
-void
+G_GNUC_COLD void
 whitelist_init(void)
 {
 	char *path;
@@ -671,7 +667,7 @@ whitelist_init(void)
 /**
  * Frees all entries in the whitelist.
  */
-void
+G_GNUC_COLD void
 whitelist_close(void)
 {
     GSList *sl;
