@@ -37,27 +37,13 @@
 #ifndef _core_whitelist_h_
 #define _core_whitelist_h_
 
-/**
- * Number of seconds between each connection attempt to a whitelisted node.
- */
-#define WHITELIST_RETRY_DELAY 30
+#include "common.h"
+#include "lib/host_addr.h"
 
-/**
- * Number of seconds between checking the whitelist file for updates.
- */
-#define WHITELIST_CHECK_INTERVAL 60
-
-struct whitelist {
-    guint32 ip;
-    guint16 port;
-    guint32 netmask;
-    time_t last_try;
-};
-
-gboolean whitelist_check(guint32 ip);
+gboolean whitelist_check(const host_addr_t addr);
 void whitelist_init(void);
 void whitelist_close(void);
 guint whitelist_connect(void);
-void whitelist_reload(void);
 
 #endif /* _core_whitelist_h_ */
+/* vi: set ts=4 sw=4 cindent: */
