@@ -1,6 +1,4 @@
 /*
- * $Id: ulq.c 19191 2011-05-30 22:18:28Z rmanfredi $
- *
  * Copyright (c) 2008, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -55,8 +53,6 @@
 
 #include "common.h"
 
-RCSID("$Id: ulq.c 19191 2011-05-30 22:18:28Z rmanfredi $")
-
 #include "ulq.h"
 #include "kuid.h"
 #include "lookup.h"
@@ -828,7 +824,7 @@ ulq_find_any_value(const kuid_t *kuid, dht_value_type_t queue_type,
  *
  * @return the created queue
  */
-static struct ulq *
+static G_GNUC_COLD struct ulq *
 ulq_init_queue(const char *name, int weight)
 {
 	struct ulq *uq;
@@ -849,7 +845,7 @@ ulq_init_queue(const char *name, int weight)
 /**
  * Initialize the user lookup queues.
  */
-void
+G_GNUC_COLD void
 ulq_init(void)
 {
 	STATIC_ASSERT(ULQ_QUEUE_COUNT == G_N_ELEMENTS(ulq));
@@ -917,7 +913,7 @@ free_fifo_item(gpointer item, gpointer data)
  *
  * @param exiting	whether the whole process is exiting
  */
-void
+G_GNUC_COLD void
 ulq_close(gboolean exiting)
 {
 	size_t i;
