@@ -1,6 +1,4 @@
 /*
- * $Id: guid.h 11378 2006-07-27 22:33:55Z rmanfredi $
- *
  * Copyright (c) 2004, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -26,14 +24,31 @@
 #ifndef _if_core_guid_h_
 #define _if_core_guid_h_
 
-#include <glib.h>
+#include "common.h"
 
 #include "lib/misc.h"		/* For GUID_RAW_SIZE */
 
 typedef struct guid {
-	guchar v[GUID_RAW_SIZE];
+	char v[GUID_RAW_SIZE];
 } guid_t;
 
-extern const gchar blank_guid[GUID_RAW_SIZE];
+/**
+ * No alignment requirements but ptr must point to GUID_RAW_SIZE or more bytes.
+ */
+static inline guid_t *
+cast_to_guid_ptr(char *ptr)
+{
+	return (guid_t *) ptr;
+}
+
+static inline const guid_t *
+cast_to_guid_ptr_const(const char *ptr)
+{
+	return (const guid_t *) ptr;
+}
+
+extern const struct guid blank_guid;
+
+gboolean guid_is_blank(const struct guid *);
 
 #endif /* _if_core_guid_h_ */
