@@ -1,6 +1,4 @@
 /*
- * $Id: http.h 12448 2006-11-24 17:01:30Z cbiere $
- *
  * Copyright (c) 2003, Raphael Manfredi
  *
  * Interface definition file.  One of the files that defines structures,
@@ -61,7 +59,7 @@ typedef struct http_range {
 
 #ifdef CORE_SOURCES
 
-const gchar *http_range_to_string(const GSList *list);
+const char *http_range_to_string(const GSList *list);
 GSList *http_range_merge(GSList *list1, GSList *list2);
 
 #endif /* CORE_SOURCES */
