@@ -1,6 +1,4 @@
 /*
- * $Id: atoms.c 19191 2011-05-30 22:18:28Z rmanfredi $
- *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -43,8 +41,6 @@
 #include "atoms.h"
 #include "endian.h"
 
-RCSID("$Id: atoms.c 19191 2011-05-30 22:18:28Z rmanfredi $")
-
 #if 0
 #define PROTECT_ATOMS
 #endif
@@ -473,7 +469,7 @@ str_str(gconstpointer v)
 /**
  * Hash `len' bytes starting from `data'.
  */
-guint
+G_GNUC_HOT guint
 binary_hash(gconstpointer data, size_t len)
 {
 	const unsigned char *key = data;
@@ -521,22 +517,7 @@ guid_hash(gconstpointer key)
 int
 guid_eq(gconstpointer a, gconstpointer b)
 {
-/* FIXME:	Disabled because of alignment problems
- *			This should work if guid was declared as guint32[4] or for
- *			architectures that require no certain alignment.
- */
-#if 0
-	const guint32 *ax = (const guint32 *) a;
-	const guint32 *bx = (const guint32 *) b;
-
-	return
-		ax[0] == bx[0] &&
-		ax[1] == bx[1] &&
-		ax[2] == bx[2] &&
-		ax[3] == bx[3];
-#else
 	return a == b || 0 == memcmp(a, b, GUID_RAW_SIZE);
-#endif
 }
 
 /**
