@@ -69,8 +69,6 @@
 
 #include "common.h"
 
-RCSID("$Id: crash.c 19191 2011-05-30 22:18:28Z rmanfredi $")
-
 #include "crash.h"
 #include "ckalloc.h"
 #include "compat_sleep_ms.h"
@@ -171,7 +169,7 @@ typedef struct cursor {
 /**
  * Append positive value to buffer, formatted as "%02u".
  */
-static void
+static G_GNUC_COLD void
 crash_append_fmt_02u(cursor_t *cursor, long v)
 {
 	if (cursor->size < 2 || v < 0)
@@ -195,7 +193,7 @@ crash_append_fmt_02u(cursor_t *cursor, long v)
 /**
  * Append positive value to buffer, formatted as "%u".
  */
-static void
+static G_GNUC_COLD void
 crash_append_fmt_u(cursor_t *cursor, unsigned long v)
 {
 	char buf[ULONG_DEC_BUFLEN];
@@ -216,7 +214,7 @@ crash_append_fmt_u(cursor_t *cursor, unsigned long v)
 /**
  * Append a character to supplied buffer.
  */
-static void
+static G_GNUC_COLD void
 crash_append_fmt_c(cursor_t *cursor, unsigned char c)
 {
 	if (cursor->size < 1)
@@ -233,7 +231,7 @@ crash_append_fmt_c(cursor_t *cursor, unsigned char c)
  * This routine can safely be used in a signal handler as it does not rely
  * on unsafe calls.
  */
-void
+G_GNUC_COLD void
 crash_time(char *buf, size_t size)
 {
 	const size_t num_reserved = 1;
@@ -276,7 +274,7 @@ crash_time(char *buf, size_t size)
  * This routine can safely be used in a signal handler as it does not rely
  * on unsafe calls.
  */
-void
+G_GNUC_COLD void
 crash_time_iso(char *buf, size_t size)
 {
 	const size_t num_reserved = 1;
@@ -317,7 +315,7 @@ crash_time_iso(char *buf, size_t size)
  * This routine can safely be used in a signal handler as it does not rely
  * on unsafe calls.
  */
-static void
+static G_GNUC_COLD void
 crash_run_time(char *buf, size_t size)
 {
 	const size_t num_reserved = 1;
@@ -365,7 +363,7 @@ crash_run_time(char *buf, size_t size)
 /**
  * Emit leading crash information: who crashed and why.
  */
-static void
+static G_GNUC_COLD void
 crash_message(const char *signame, gboolean trace, gboolean recursive)
 {
 	DECLARE_STR(11);
@@ -418,7 +416,7 @@ crash_message(const char *signame, gboolean trace, gboolean recursive)
 /**
  * Marks end of crash logging and potential pausing or debugger hook calling.
  */
-static void
+static G_GNUC_COLD void
 crash_end_of_line(void)
 {
 	DECLARE_STR(7);
@@ -452,7 +450,7 @@ crash_end_of_line(void)
 /**
  * Construct name of GTKG crash log.
  */
-static void
+static G_GNUC_COLD void
 crash_logname(char *buf, size_t len, const char *pidstr)
 {
 	clamp_strcpy(buf, len, EMPTY_STRING(vars->progname));
@@ -480,7 +478,7 @@ crash_logname(char *buf, size_t len, const char *pidstr)
  * Emit the current stack frame to specified file, or the assertion stack
  * if we have one.
  */
-static NO_INLINE void
+static G_GNUC_COLD NO_INLINE void
 crash_stack_print(int fd, size_t offset)
 {
 	if (vars != NULL && vars->stackcnt != 0) {
@@ -495,7 +493,7 @@ crash_stack_print(int fd, size_t offset)
  * Invoke the inspector process (gdb, or any other program specified at
  * initialization time).
  */
-static void
+static G_GNUC_COLD void
 crash_invoke_inspector(int signo, const char *cwd)
 {
    	const char *pid_str;
@@ -981,7 +979,7 @@ parent_failure:
 /**
  * The signal handler used to trap harmful signals.
  */
-void
+G_GNUC_COLD void
 crash_handler(int signo)
 {
 	static volatile sig_atomic_t crashed;
@@ -1115,7 +1113,7 @@ crash_handler(int signo)
  * @param flags		any combination of CRASH_F_GDB and CRASH_F_PAUSE
  * @parah exec_path	pathname of custom program to execute on crash
  */
-void
+G_GNUC_COLD void
 crash_init(const char *argv0, const char *progname,
 	int flags, const char *exec_path)
 {
@@ -1238,7 +1236,7 @@ G_STMT_START { \
  * @param dst_size The size of the destination buffer in bytes.
  * @return Required buffer size.
  */
-static size_t
+static G_GNUC_COLD size_t
 crashfile_name(char *dst, size_t dst_size, const char *pathname)
 {
 	const char *pid_str, *item;
@@ -1277,7 +1275,7 @@ crashfile_name(char *dst, size_t dst_size, const char *pathname)
 /**
  * Record current working directory and configured crash directory.
  */
-void
+G_GNUC_COLD void
 crash_setdir(const char *pathname)
 {
 	const char *curdir = NULL;
@@ -1334,7 +1332,7 @@ crash_setdir(const char *pathname)
 /**
  * Record program's version string.
  */
-void
+G_GNUC_COLD void
 crash_setver(const char *version)
 {
 	const char *value;
@@ -1384,7 +1382,7 @@ crash_assert_failure(const struct assertion_data *a)
  * Save given stack trace, which will be displayed during crashes instead
  * of the current stack frame.
  */
-void
+G_GNUC_COLD void
 crash_save_stackframe(void *stack[], size_t count)
 {
 	if (count > G_N_ELEMENTS(vars->stack))
@@ -1404,7 +1402,7 @@ crash_save_stackframe(void *stack[], size_t count)
  * is to protect against SIGABRT signal delivery happening on a dedicated
  * signal stack.
  */
-void
+G_GNUC_COLD void
 crash_save_current_stackframe(void)
 {
 	if (vars != NULL) {
