@@ -1,6 +1,4 @@
 /*
- * $Id: dbmw.c 19236 2011-06-04 10:53:58Z rmanfredi $
- *
  * Copyright (c) 2008-2009, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -36,8 +34,6 @@
 
 #include "common.h"
 
-RCSID("$Id: dbmw.c 19236 2011-06-04 10:53:58Z rmanfredi $")
-
 #include "debug.h"
 #include "dbmw.h"
 #include "dbmap.h"
@@ -846,7 +842,7 @@ dbmw_write(dbmw_t *dw, gconstpointer key, gpointer value, size_t length)
  * @return pointer to value, or NULL if it was either not found or the
  * deserialization failed.
  */
-gpointer
+G_GNUC_HOT gpointer
 dbmw_read(dbmw_t *dw, gconstpointer key, size_t *lenptr)
 {
 	struct cached *entry;
