@@ -1,6 +1,4 @@
 /*
- * $Id: host_addr.c 19266 2011-06-15 16:02:31Z rmanfredi $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi
  * Copyright (c) 2005, Christian Biere
  *
@@ -36,8 +34,6 @@
 
 #include "common.h"
 
-RCSID("$Id: host_addr.c 19266 2011-06-15 16:02:31Z rmanfredi $")
-
 #ifdef I_NET_IF
 #include <net/if.h>		/* For IFF_* flags */
 #endif /* I_NET_IF */
@@ -1462,13 +1458,11 @@ host_pack(const host_addr_t addr, guint16 port)
 	return phost;
 }
 
-void
-packed_host_unpack(const struct packed_host *phost,	/* MUST be a pointer */
-	host_addr_t *addr_ptr, guint16 *port_ptr)
+G_GNUC_HOT void
+packed_host_unpack_addr(
+	const struct packed_host *phost,	/* MUST be a pointer */
+	host_addr_t *addr_ptr)
 {
-	if (port_ptr) {
-		*port_ptr = peek_be16(&phost->port);
-	}
 	switch (phost->ha.net) {
 	case NET_TYPE_IPV4:
 		if (addr_ptr) {
