@@ -1,6 +1,4 @@
 /*
- * $Id: host_addr.h 19266 2011-06-15 16:02:31Z rmanfredi $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi
  * Copyright (c) 2005, Christian Biere
  *
@@ -265,7 +263,7 @@ host_addr_ipv6(const host_addr_t *ha)
 	return NET_TYPE_IPV6 == ha->net ? ha->addr.ipv6 : NULL;
 }
 
-static inline host_addr_t
+static inline G_GNUC_CONST host_addr_t
 host_addr_get_ipv4(guint32 ip)
 {
 	host_addr_t ha;
@@ -275,13 +273,13 @@ host_addr_get_ipv4(guint32 ip)
 	return ha;
 }
 
-static inline host_addr_t
+static inline G_GNUC_PURE host_addr_t
 host_addr_peek_ipv4(const void *ipv4)
 {
 	return host_addr_get_ipv4(peek_be32(ipv4));
 }
 
-static inline host_addr_t
+static inline G_GNUC_PURE host_addr_t
 host_addr_peek_ipv6(const guint8 *ipv6)
 {
 	host_addr_t ha;
@@ -399,7 +397,7 @@ host_addr_matches(const host_addr_t a, const host_addr_t b, guint8 bits)
 }
 
 
-static inline gboolean
+static inline G_GNUC_PURE gboolean
 is_host_addr(const host_addr_t ha)
 {
 	switch (host_addr_net(ha)) {
@@ -614,13 +612,13 @@ host_addr_t packed_host_addr_unpack(const struct packed_host_addr paddr);
 
 guint packed_host_size(const struct packed_host paddr);
 struct packed_host host_pack(const host_addr_t addr, guint16 port);
-void packed_host_unpack(const struct packed_host *phost,
-		host_addr_t *addr_ptr, guint16 *port_ptr);
-
+void packed_host_unpack_addr(const struct packed_host *phost,
+	host_addr_t *addr_ptr);
 guint packed_host_hash_func(gconstpointer key);
 gboolean packed_host_eq_func(gconstpointer p, gconstpointer q);
 gpointer walloc_packed_host(const host_addr_t addr, guint16 port);
 void wfree_packed_host(gpointer key, gpointer unused_data);
 
 #endif /* _host_addr_h_ */
+
 /* vi: set ts=4 sw=4 cindent: */
