@@ -1,6 +1,4 @@
 /*
- * $Id: iso3166.c 12136 2006-10-24 23:55:35Z cbiere $
- *
  * Copyright (c) 2004, Christian Biere
  *
  *----------------------------------------------------------------------
@@ -35,17 +33,16 @@
 
 #include "common.h"
 
-RCSID("$Id: iso3166.c 12136 2006-10-24 23:55:35Z cbiere $")
-
+#include "ascii.h"
 #include "atoms.h"
 #include "iso3166.h"
-#include "misc.h"
+#include "parse.h"
 
 #include "override.h"       /* Must be the last header included */
 
 typedef struct {
-	gchar *country;	/* atom */
-	gchar cc[3];
+	const char *country;	/* atom */
+	char cc[3];
 } iso3166_entry_t;
 
 /**
@@ -187,7 +184,7 @@ static const struct {
 	{ "kz", N_("Kazakhstan") },
 	{ "la", N_("Laos") },
 	{ "lb", N_("Lebanon") },
-	{ "lc", N_("Saint lucia") },
+	{ "lc", N_("Saint Lucia") },
 	{ "li", N_("Liechtenstein") },
 	{ "lk", N_("Sri Lanka") },
 	{ "lr", N_("Liberia") },
@@ -200,6 +197,7 @@ static const struct {
 	{ "mc", N_("Monaco") },
 	{ "md", N_("Moldova") },
 	{ "me", N_("Montenegro") },
+	{ "mf", N_("Saint Martin") },
 	{ "mg", N_("Madagascar") },
 	{ "mh", N_("Marshall Islands") },
 	{ "mk", N_("Macedonia") },
@@ -310,23 +308,22 @@ static const struct {
 
 static iso3166_entry_t iso3166_entries[G_N_ELEMENTS(iso3166_tab)];
 
-#define NUM_CODES (36 * 35 + 35)
-static iso3166_entry_t *iso3166_countries[NUM_CODES];
+static iso3166_entry_t *iso3166_countries[ISO3166_NUM_CODES];
 
 /**
- * Decodes a valid 2-letter country code into an integer.
+ * Decodes a valid country code into a 2-letter country string.
  *
- * @return NULL integer isn't a validly encoded country code. If the country
+ * @return NULL if integer isn't a validly encoded country code. If the country
  *		   is valid, a string pointing two the 2-letter code is returned. The
  *		   string is in a static buffer.
  */
-static const gchar *
-iso3166_decode_cc(gint code)
+static const char *
+iso3166_decode_cc(guint16 code)
 {
-    static gchar s[3];
-    gint i;
+    static char s[3];
+    guint i;
 
-    if (code < 0 || (size_t) code >= G_N_ELEMENTS(iso3166_countries))
+    if (code >= G_N_ELEMENTS(iso3166_countries))
         return NULL;
 
     if (NULL == iso3166_countries[code])
@@ -344,34 +341,36 @@ iso3166_decode_cc(gint code)
 /**
  * Encodes a valid 2-letter country code into an integer.
  *
- * @return -1 if the given string is obviously not a 2-letter country code.
+ * @return ISO3166_INVALID if the given string is obviously not
+ *         a 2-letter country code.
  */
-gint
-iso3166_encode_cc(const gchar *cc)
+guint16
+iso3166_encode_cc(const char *cc)
 {
     g_assert(cc != NULL);
 
     if (is_ascii_alnum(cc[0]) && is_ascii_alnum(cc[1]) && '\0' == cc[2]) {
-        const gchar *d;
-		guint32 v;
-		gint error;
+        const char *d;
+		guint16 code;
+		int error;
 
-		v = parse_uint32(cc, NULL, 36, &error);
-        g_assert(v < G_N_ELEMENTS(iso3166_countries));
-        g_assert(0 == error);
+		code = parse_uint16(cc, NULL, 36, &error);
 
-		if (NULL != iso3166_countries[v]) {
-			gint code = v;
+		if (code >= G_N_ELEMENTS(iso3166_countries))
+			return ISO3166_INVALID;
+
+		g_assert(0 == error);
+
+		if (NULL != iso3166_countries[code]) {
         	d = iso3166_decode_cc(code);
         	g_assert(0 == ascii_strcasecmp(cc, d));
 			return code;
 		}
     }
-    return -1;
+    return ISO3166_INVALID;
 }
 
-
-void
+G_GNUC_COLD void
 iso3166_init(void)
 {
 	size_t i;
@@ -384,20 +383,20 @@ iso3166_init(void)
 		entry->country = atom_str_get(_(iso3166_tab[i].country));
 
 		{
-			const gchar *endptr;
-			gint code, error;
+			const char *endptr;
+			guint16 code;
+			int error;
 
-			code = parse_uint32(entry->cc, &endptr, 36, &error);
+			code = parse_uint16(entry->cc, &endptr, 36, &error);
 			g_assert(*endptr == '\0');
 			g_assert(!error);
-			g_assert(code >= 0);
 			g_assert((size_t) code < G_N_ELEMENTS(iso3166_countries));
 			iso3166_countries[code] = entry;
 		}
 	}
 }
 
-void
+G_GNUC_COLD void
 iso3166_close(void)
 {
 	size_t i;
@@ -408,6 +407,19 @@ iso3166_close(void)
 	}
 }
 
+static inline const iso3166_entry_t *
+iso3166_country_entry(guint16 code)
+{
+	if (ISO3166_INVALID == code) {
+		static const iso3166_entry_t unknown = { "??", "??" };
+		return &unknown;
+	} else {
+		static const iso3166_entry_t none = { "(null)", "??" };
+		g_assert(code < G_N_ELEMENTS(iso3166_countries));
+		return iso3166_countries[code] ? iso3166_countries[code] : &none;
+	}
+}
+
 /**
  * Maps a valid encoded country code to the country name.
  *
@@ -415,17 +427,10 @@ iso3166_close(void)
  *		   is valid, a string pointing two the country name is returned. Each
  *		   string has its own buffer which is only free()d by iso3166_close().
  */
-const gchar *
-iso3166_country_name(gint code)
+const char *
+iso3166_country_name(guint16 code)
 {
-	iso3166_entry_t *e;
-
-	g_assert(code >= -1 && code < (gint) G_N_ELEMENTS(iso3166_countries));
-	if (-1 == code)
-		return "??";
-
-	e = iso3166_countries[code];
-	return e ? e->country : "(null)";
+	return iso3166_country_entry(code)->country;
 }
 
 /**
@@ -435,17 +440,10 @@ iso3166_country_name(gint code)
  *		   is valid, a string pointing two the 2-letter code is returned. Each
  *		   string has its own buffer which is only free()d by iso3166_close().
  */
-const gchar *
-iso3166_country_cc(gint code)
+const char *
+iso3166_country_cc(guint16 code)
 {
-	iso3166_entry_t *e;
-
-	g_assert(code >= -1 && code < (gint) G_N_ELEMENTS(iso3166_countries));
-	if (-1 == code)
-		return "??";
-
-	e = iso3166_countries[code];
-	return e ? e->cc : "(null)";
+	return iso3166_country_entry(code)->cc;
 }
 
 /* vi: set ts=4 sw=4 cindent: */
