@@ -1,6 +1,4 @@
 /*
- * $Id: map.c 19142 2011-05-23 20:44:04Z rmanfredi $
- *
  * Copyright (c) 2008, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "common.h"
 
-RCSID("$Id: map.c 19142 2011-05-23 20:44:04Z rmanfredi $")
-
 #include "map.h"
 #include "debug.h"
 #include "random.h"
@@ -644,7 +640,7 @@ test_map_remove(void *o, sha1_t *keys, size_t count)
 		map_remove(m, &keys[i]);
 }
 
-static double
+static G_GNUC_COLD double
 timeit(
 	void (*f)(void *, sha1_t *, size_t),
 	void *o, sha1_t *keys, size_t count, size_t iter, const char *what,
@@ -668,7 +664,7 @@ timeit(
 	return elapsed;
 }
 
-void
+G_GNUC_COLD void
 map_test(void)
 {
 	sha1_t *keys;
