@@ -1,6 +1,4 @@
 /*
- * $Id: mingw32.c 19191 2011-05-30 22:18:28Z rmanfredi $
- *
  * Copyright (c) 2010, Jeroen Asselman & Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -42,8 +40,6 @@
 
 #ifdef MINGW32
 
-RCSID("$Id: mingw32.c 19191 2011-05-30 22:18:28Z rmanfredi $")
-
 #include <stdlib.h>
 #include <windows.h>
 #include <mswsock.h>
@@ -487,7 +483,7 @@ mingw_signal(int signo, signal_handler_t handler)
 /**
  * Synthesize a fatal signal as the kernel would on an exception.
  */
-static void
+static G_GNUC_COLD void
 mingw_sigraise(int signo)
 {
 	g_assert(signo > 0 && signo < SIGNAL_COUNT);
@@ -784,15 +780,25 @@ mingw_patch_personal_path(const char *pathname)
 	p = is_strprefix(pathname, home);
 	if (p != NULL && !is_directory(pathname)) {
 		char *patched;
+		if (is_strsuffix(pathname, -1, "gtk-gnutella-downloads/complete")) {
+			/* 
+			 * Put the gtk-gnutella-downloads/complete into the downloads folder
+			 * as this is where the user would expect completed downloads to be
+			 * be placed
+			 * 	-- JA 29/7/2011
+			 */
+			patched = h_strdup(
+				g_get_user_special_dir(G_USER_DIRECTORY_DOWNLOAD));
+		} else {
+			/*
+			 * Put everything else under "My Documents/gtk-gnutella", were
+			 * we should already find stdout and stderr files created when
+			 * running from the GUI.
+			 */
 
-		/*
-		 * Put everything under "My Documents/gtk-gnutella", were we should
-		 * already find stdout and stderr files created when running from
-		 * the GUI.
-		 */
-
-		patched = h_strconcat(mingw_getpersonal(),
-			G_DIR_SEPARATOR_S, GTA_PRODUCT_NAME, p, (void *) 0);
+			patched = h_strconcat(mingw_getpersonal(),
+				G_DIR_SEPARATOR_S, GTA_PRODUCT_NAME, p, (void *) 0);
+		}
 		s_debug("patched \"%s\" into \"%s\"", pathname, patched);
 		return patched;
 	} else {
@@ -1436,7 +1442,7 @@ mingw_valloc(void *hint, size_t size)
 	void *p = NULL;
 
 	if (NULL == hint && mingw_vmm_res_nonhinted >= 0) {
-		if (NULL == mingw_vmm_res_mem) {
+		if G_UNLIKELY(NULL == mingw_vmm_res_mem) {
 			MEMORYSTATUSEX memStatus;
 			SYSTEM_INFO system_info;
 			void *mem_later;
@@ -2285,7 +2291,7 @@ mingw_adns_getaddrinfo(const struct adns_request *req)
 	struct async_data *ad;
 	
 	if (common_dbg > 2) {
-		t_debug(altc, "%s", G_STRFUNC);
+		g_debug("%s", G_STRFUNC);
 	}	
 	g_assert(req);
 	g_assert(req->common.user_callback);
@@ -2746,7 +2752,7 @@ mingw_backtrace(void **buffer, int size)
 /**
  * Convert exception code to string.
  */
-static const char *
+static G_GNUC_COLD const char *
 mingw_exception_to_string(int code)
 {
 	switch (code) {
@@ -2777,7 +2783,7 @@ mingw_exception_to_string(int code)
 /**
  * Log reported exception.
  */
-static void
+static G_GNUC_COLD void
 mingw_exception_log(int code, const void *pc)
 {
 	DECLARE_STR(9);
@@ -2809,7 +2815,7 @@ mingw_exception_log(int code, const void *pc)
 /**
  * Log extra information on memory faults.
  */
-static void
+static G_GNUC_COLD void
 mingw_memory_fault_log(const EXCEPTION_RECORD *er)
 {
 	DECLARE_STR(6);
@@ -2852,7 +2858,7 @@ mingw_in_exception(void)
 /**
  * Our default exception handler.
  */
-static LONG WINAPI
+static G_GNUC_COLD LONG WINAPI
 mingw_exception(EXCEPTION_POINTERS *ei)
 {
 	EXCEPTION_RECORD *er;
@@ -3003,7 +3009,7 @@ mingw_stdio_reset(void)
 	close(STDERR_FILENO);
 }
 
-void
+G_GNUC_COLD void
 mingw_early_init(void)
 {
 	int console_err;
