@@ -1,6 +1,4 @@
 /*
- * $Id: misc.c 19094 2011-05-15 11:18:38Z rmanfredi $
- *
  * Copyright (c) 2001-2008, Raphael Manfredi
  * Copyright (c) 2003-2008, Christian Biere
  *
@@ -38,8 +36,6 @@
 
 #include "common.h"
 
-RCSID("$Id: misc.c 19094 2011-05-15 11:18:38Z rmanfredi $")
-
 #include "ascii.h"
 #include "atoms.h"
 #include "base16.h"
@@ -937,7 +933,7 @@ alnum2int(guchar c)
 /**
  * Initializes the lookup table for hex2int().
  */
-static void
+static G_GNUC_COLD void
 hex2int_init(void)
 {
 	size_t i;
@@ -985,7 +981,7 @@ hex2int_init(void)
 /**
  * Initializes the lookup table for dec2int().
  */
-static void
+static G_GNUC_COLD void
 dec2int_init(void)
 {
 	size_t i;
@@ -1021,7 +1017,7 @@ dec2int_init(void)
 /**
  * Initializes the lookup table for alnum2int().
  */
-static void
+static G_GNUC_COLD void
 alnum2int_init(void)
 {
 	static const char abc[] = "0123456789abcdefghijklmnopqrstuvwxyz";
@@ -1110,8 +1106,13 @@ sha1_to_base32_buf(const struct sha1 *sha1, char *dst, size_t size)
 {
 	g_assert(sha1);
 	if (size > 0) {
-		base32_encode(dst, size, sha1->data, sizeof sha1->data);
-		dst[size - 1] = '\0';
+		size_t len;
+		size_t offset;
+
+		len = base32_encode(dst, size, sha1->data, sizeof sha1->data);
+		g_assert(len <= size);
+		offset = len < size ? len : size - 1;
+		dst[offset] = '\0';
 	}
 	return dst;
 }
@@ -1130,6 +1131,45 @@ sha1_base32(const struct sha1 *sha1)
 	return sha1_to_base32_buf(sha1, digest_b32, sizeof digest_b32);
 }
 
+/**
+ * Convert binary SHA1 into a base16 string.
+ *
+ * @param dst The destination buffer for the string.
+ * @param size The size of "dst" in bytes; should be larger than
+ *             SHA1_BASE16_SIZE, otherwise the resulting string will be
+ *             truncated.
+ * @return dst.
+ */
+char *
+sha1_to_base16_buf(const struct sha1 *sha1, char *dst, size_t size)
+{
+	g_assert(sha1);
+	if (size > 0) {
+		size_t len;
+		size_t offset;
+
+		len = base16_encode(dst, size, sha1->data, sizeof sha1->data);
+		g_assert(len <= size);
+		offset = len < size ? len : size - 1;
+		dst[offset] = '\0';
+	}
+	return dst;
+}
+
+/**
+ * Convert binary SHA1 into a base16 string.
+ *
+ * @return pointer to static data.
+ */
+const char *
+sha1_base16(const struct sha1 *sha1)
+{
+	static char digest_b16[SHA1_BASE16_SIZE + 1];
+
+	g_assert(sha1);
+	return sha1_to_base16_buf(sha1, digest_b16, sizeof digest_b16);
+}
+
 const char *
 sha1_to_string(const struct sha1 *sha1)
 {
@@ -1331,7 +1371,7 @@ tth_to_urn_string(const struct tth *tth)
  * @return the number of common leading bits, which is at most
  * min(k1bits, k2bits) if everything matches.
  */
-size_t
+G_GNUC_HOT size_t
 common_leading_bits(
 	gconstpointer k1, size_t k1bits, gconstpointer k2, size_t k2bits)
 {
@@ -1625,7 +1665,7 @@ failure:
 /**
  * Find amount of common leading bits between two IP addresses.
  */
-static guint8
+static G_GNUC_HOT guint8
 find_common_leading(guint32 ip1, guint32 ip2)
 {
 	guint8 n;
@@ -1816,7 +1856,7 @@ html_escape(const char *src, char *dst, size_t dst_size)
 
 static GHashTable *html_entities_lut;
 
-static void
+static G_GNUC_COLD void
 html_entities_init(void)
 {
 	size_t i;
@@ -2100,7 +2140,7 @@ symbolic_errno(int errnum)
 /**
  * Initialize miscellaneous data structures.
  */
-void
+G_GNUC_COLD void
 misc_init(void)
 {
 	hex2int_init();
