@@ -1,6 +1,4 @@
 /*
- * $Id: misc.h 18970 2011-04-12 18:07:56Z rmanfredi $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -64,7 +62,7 @@ typedef struct short_string {
 	char str[SIZE_FIELD_MAX];
 } short_string_t;
 
-static inline int
+static inline G_GNUC_CONST ALWAYS_INLINE int 
 is_dir_separator(int c)
 {
 	return '/' == c || G_DIR_SEPARATOR == c;
@@ -77,7 +75,7 @@ is_dir_separator(int c)
  * @param x An integer between 0 and 15.
  * @return The ASCII character corresponding to the hex digit [0-9a-f].
  */
-static inline guchar
+static inline G_GNUC_PURE ALWAYS_INLINE guchar
 hex_digit(guchar x)
 {
 	extern const char hex_alphabet_lower[];
@@ -154,9 +152,11 @@ const char *sha1_to_urn_string(const struct sha1 *);
 size_t sha1_to_urn_string_buf(const struct sha1 *, char *dst, size_t size);
 char *sha1_to_base32_buf(const struct sha1 *, char *dst, size_t size);
 const char *sha1_base32(const struct sha1 *);
+char *sha1_to_base16_buf(const struct sha1 *, char *dst, size_t size);
+const char *sha1_base16(const struct sha1 *);
 const struct sha1 *base32_sha1(const char *base32);
 
-static inline int
+static inline G_GNUC_PURE int
 sha1_cmp(const struct sha1 *a, const struct sha1 *b)
 {
 	return memcmp(a, b, SHA1_RAW_SIZE);
@@ -264,7 +264,8 @@ void dump_string(FILE *out, const char *str, size_t len, const char *trailer);
 gboolean is_printable_iso8859_string(const char *s);
 void locale_strlower(char *, const char *);
 size_t common_leading_bits(
-	gconstpointer k1, size_t k1bits, gconstpointer k2, size_t k2bits);
+	gconstpointer k1, size_t k1bits, gconstpointer k2, size_t k2bits)
+	G_GNUC_PURE;
 float force_range(float value, float min, float max);
 const char *short_filename(const char *fullname);
 char *data_hex_str(const char *data, size_t len);
@@ -509,11 +510,11 @@ swap_guint32(guint32 i)
  */
 static inline G_GNUC_CONST WARN_UNUSED_RESULT guint8
 netmask_to_cidr(guint32 netmask)
-#ifdef HAVE_BUILTIN_POPCOUNT
+#ifdef HAS_BUILTIN_POPCOUNT
 {
-	__builtin_popcount(netmask);
+	return __builtin_popcount(netmask);
 }
-#else	/* HAVE_BUILTIN_POPCOUNT */
+#else	/* !HAS_BUILTIN_POPCOUNT */
 {
 	guint8 bits = 32;
 
@@ -523,7 +524,7 @@ netmask_to_cidr(guint32 netmask)
 	}
 	return bits;
 }
-#endif /* HAVE_BUILTIN_POPCOUNT */
+#endif /* HAS_BUILTIN_POPCOUNT */
 
 /**
  * Converts the CIDR prefix length to a IPv4 netmask in host byte order.
