@@ -1,6 +1,4 @@
 /*
- * $Id: omalloc.h 17569 2010-10-26 22:40:07Z rmanfredi $
- *
  * Copyright (c) 2010 Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -36,9 +34,9 @@
 #ifndef _omalloc_h_
 #define _omalloc_h_
 
-void *omalloc(size_t size);
-void *omalloc0(size_t size);
-char *ostrdup(const char *str);
+void *omalloc(size_t size) WARN_UNUSED_RESULT G_GNUC_MALLOC;
+void *omalloc0(size_t size) WARN_UNUSED_RESULT G_GNUC_MALLOC;
+char *ostrdup(const char *str) WARN_UNUSED_RESULT G_GNUC_MALLOC;
 
 size_t omalloc_page_count(void);
 void set_omalloc_debug(guint32 level);
