@@ -1,6 +1,4 @@
 /*
- * $Id: palloc.c 19142 2011-05-23 20:44:04Z rmanfredi $
- *
  * Copyright (c) 2005, 2009, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -61,8 +59,6 @@
 
 #include "common.h"
 
-RCSID("$Id: palloc.c 19142 2011-05-23 20:44:04Z rmanfredi $")
-
 #include "cq.h"
 #include "hashlist.h"
 #include "glib-missing.h"
@@ -306,7 +302,7 @@ pool_free(pool_t *p)
 /**
  * Allocate buffer from the pool.
  */
-gpointer
+G_GNUC_HOT gpointer
 palloc(pool_t *p)
 {
 	pool_check(p);
@@ -323,7 +319,7 @@ palloc(pool_t *p)
 		g_assert(uint_is_positive(p->held));
 
 		obj = p->buffers->data;
-		p->buffers = g_slist_remove(p->buffers, obj);
+		p->buffers = g_slist_delete_link(p->buffers, p->buffers);
 		p->held--;
 
 		return obj;
