@@ -1,6 +1,4 @@
 /*
- * $Id: path.c 18596 2011-01-30 21:12:45Z rmanfredi $
- *
  * Copyright (c) 2009, Raphael Manfredi
  * Copyright (c) 2006-2008, Christian Biere
  *
@@ -38,8 +36,6 @@
 
 #include "common.h"
 
-RCSID("$Id: path.c 18596 2011-01-30 21:12:45Z rmanfredi $")
-
 #include "ascii.h"
 #include "path.h"
 #include "misc.h"
@@ -231,4 +227,43 @@ filepath_directory(const char *pathname)
 	return dir;
 }
 
+/**
+ * Compute special folder path.
+ *
+ * @param which_folder		the special folder token
+ * @param path				sub-path undernead the special folder
+ *
+ * @return halloc()'ed full path, NULL if special folder is unknown.
+ */
+char *
+get_folder_path(enum special_folder which_folder, const char *path)
+{
+	char *pathname;
+	size_t offset = 0;	
+	char *special_path = NULL;
+
+	switch (which_folder) {
+	case PRIVLIB_PATH:	special_path = getenv("XDG_DATA_DIRS"); break;
+	}
+	
+	if (NULL == special_path)
+		return NULL;
+	
+	pathname = halloc0(MAX_PATH_LEN);
+			
+	offset += clamp_strcpy(
+		&pathname[offset], MAX_PATH_LEN - offset, special_path);
+		
+	offset += clamp_strcpy(
+		&pathname[offset], MAX_PATH_LEN - offset, 
+			G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S);
+
+	if (path != NULL) {
+		offset += clamp_strcpy(
+			&pathname[offset], MAX_PATH_LEN - offset, path);
+	}
+	
+	return pathname;
+}
+
 /* vi: set ts=4 sw=4 cindent: */
