@@ -1,6 +1,4 @@
 /*
- * $Id: pattern.c 19142 2011-05-23 20:44:04Z rmanfredi $
- *
  * Copyright (c) 2001-2004, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "common.h"
 
-RCSID("$Id: pattern.c 19142 2011-05-23 20:44:04Z rmanfredi $")
-
 #include "misc.h"
 #include "pattern.h"
 #include "halloc.h"
@@ -110,7 +106,7 @@ pattern_compile(const char *pattern)
  * @attention
  * NB: There is no pattern_free_fast(), just call zfree() on the result.
  */
-cpattern_t *
+G_GNUC_HOT cpattern_t *
 pattern_compile_fast(const char *pattern, size_t plen)
 {
 	cpattern_t *p;
@@ -157,7 +153,7 @@ pattern_free(cpattern_t *cpat)
  *
  * @return pointer to beginning of matching substring, NULL if not found.
  */
-const char *
+G_GNUC_HOT const char *
 pattern_qsearch(
 	cpattern_t *cpat,		/**< Compiled pattern */
 	const char *text,		/**< Text we're scanning */
