@@ -1,6 +1,4 @@
 /*
- * $Id: stacktrace.h 18878 2011-03-17 23:25:51Z rmanfredi $
- *
  * Copyright (c) 2004, 2010 Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -61,8 +59,8 @@ struct stackatom {
 /**
  * Hashing /equality functions for "struct stacktracea" atomic traces.
  */
-size_t stack_hash(const void *key);
-int stack_eq(const void *a, const void *b);
+size_t stack_hash(const void *key) G_GNUC_PURE;
+int stack_eq(const void *a, const void *b) G_GNUC_PURE;
 
 void stacktrace_get(struct stacktrace *st);
 void stacktrace_get_offset(struct stacktrace *st, size_t offset);
