@@ -1,6 +1,4 @@
 /*
- * $Id: vendors.c 17427 2010-05-07 20:53:46Z cbiere $
- *
  * Copyright (c) 2001-2003, Richard Eckart
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "common.h"
 
-RCSID("$Id: vendors.c 17427 2010-05-07 20:53:46Z cbiere $")
-
 #include "vendors.h"
 #include "ascii.h"
 #include "endian.h"
@@ -134,7 +130,7 @@ static const struct vendor {
  *
  * @returns vendor string if found, NULL otherwise.
  */
-static const char *
+static G_GNUC_HOT const char *
 find_vendor(guint32 code)
 {
 #define GET_KEY(i) (vendor_map[(i)].code)
@@ -259,7 +255,7 @@ vendor_get_name(guint32 code)
 /**
  * Initialize the vendor lookup.
  */
-void
+G_GNUC_COLD void
 vendor_init(void)
 {
 	BINARY_ARRAY_SORTED(vendor_map, struct vendor, code,
