@@ -1,6 +1,4 @@
 /*
- * $Id: zalloc.c 19325 2011-07-07 12:48:24Z rmanfredi $
- *
  * Copyright (c) 2002-2003, 2009-2010 Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -58,8 +56,6 @@
 
 #include "common.h"
 
-RCSID("$Id: zalloc.c 19325 2011-07-07 12:48:24Z rmanfredi $")
-
 #include "zalloc.h"
 #include "hashtable.h"
 #include "glib-missing.h"	/* For g_mem_is_system_malloc() */
@@ -306,7 +302,7 @@ zprepare(zone_t *zone, char **blk)
  * @return a pointer to a block containing at least 'size' bytes of
  * memory.  It is a fatal error if memory cannot be allocated.
  */
-void *
+G_GNUC_HOT void *
 zalloc(zone_t *zone)
 {
 	char **blk;		/**< Allocated block */
@@ -1050,7 +1046,7 @@ free_zone(const void *u_key, void *value, void *u_data)
  * Close the zone allocator, destroying all the remaining zones regardless
  * of their reference count.
  */
-void
+G_GNUC_COLD void
 zclose(void)
 {
 	if (NULL == zt)
@@ -1176,7 +1172,7 @@ subzinfo_cmp(const void *a, const void *b)
  *
  * @return a pointer to the found subzone information, NULL if not found.
  */
-static struct subzinfo *
+static G_GNUC_HOT struct subzinfo *
 zgc_find_subzone(struct zone_gc *zg, void *blk, unsigned *low_ptr)
 {
 	struct subzinfo *item, *array = zg->zg_subzinfo;
@@ -1214,7 +1210,7 @@ zgc_find_subzone(struct zone_gc *zg, void *blk, unsigned *low_ptr)
 /**
  * Check whether address falls within the subzone boundaries.
  */
-static inline gboolean
+static inline G_GNUC_HOT gboolean
 zgc_within_subzone(const struct subzinfo *szi, const void *p)
 {
 	struct subzone *sz;
@@ -1930,7 +1926,7 @@ zgc_dispose(zone_t *zone)
 /**
  * Allocate a block from the first subzone with free items.
  */
-static void *
+static G_GNUC_HOT void *
 zgc_zalloc(zone_t *zone)
 {
 	struct zone_gc *zg = zone->zn_gc;
@@ -2280,7 +2276,7 @@ zgc(gboolean overloaded)
 /**
  * Initialize zone allocator.
  */
-void
+G_GNUC_COLD void
 zinit(void)
 {
 	addr_grows_upwards = vmm_grows_upwards();
