@@ -1,6 +1,4 @@
 /*
- * $Id: main.c 19325 2011-07-07 12:48:24Z rmanfredi $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi
  *
  *----------------------------------------------------------------------
@@ -166,8 +164,6 @@
 
 #include "lib/override.h"		/* Must be the last header included */
 
-RCSID("$Id: main.c 19325 2011-07-07 12:48:24Z rmanfredi $")
-
 #define SLOW_UPDATE_PERIOD		20	/**< Update period for `main_slow_update' */
 #define EXIT_GRACE				30	/**< Seconds to wait before exiting */
 #define ATEXIT_TIMEOUT			20	/**< Final cleanup must not take longer */
@@ -266,6 +262,39 @@ main_get_build(void)
 	return build;
 }
 
+/**
+ * Get full build number string.
+ */
+const char *
+main_get_build_full(void)
+{
+	static char *result;
+
+	if (NULL == result) {
+		const char *p;
+		p = is_strprefix(GTA_BUILD, "$Revision: ");
+		if (p != NULL) {
+			char *tmp;
+			char *q;
+			size_t len = strlen(p) + 2;		/* Leading '-', trailing NUL */
+
+			tmp = halloc(len);
+			g_strlcpy(tmp + 1, p, len - 1);
+			*tmp = '-';
+			q = strchr(tmp, ' ');
+			if (q != NULL)
+				*q = '\0';		/* Truncate at first space */
+
+			result = ostrdup(tmp);
+			HFREE_NULL(tmp);
+		} else {
+			result = "";		/* No change since last git tag */
+		}
+	}
+
+	return result;
+}
+
 /**
  * Are we debugging anything at a level greater than some threshold "t"?
  */
