@@ -1,6 +1,4 @@
 /*
- * $Id: icon.c 15043 2007-12-02 21:54:41Z cbiere $
- *
  * Copyright (c) 2003, Michael Gray
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "gui.h"
 
-RCSID("$Id: icon.c 15043 2007-12-02 21:54:41Z cbiere $")
-
 #include "icon.h"
 
 #ifdef USE_GTK2
@@ -462,7 +458,7 @@ status_icon_init(void)
  * See --
  *    http://tronche.com/gui/x/icccm/sec-4.html#s-4.1.9
  */
-void
+G_GNUC_COLD void
 icon_init(void)
 {
     create_icon();
@@ -519,7 +515,7 @@ icon_close(void)
 static GdkPixmap *icon_map;
 static GdkBitmap *icon_mask;
 
-void
+G_GNUC_COLD void
 icon_init(void)
 {
     GtkPixmap *pixmap;
@@ -531,7 +527,7 @@ icon_init(void)
 void
 icon_close(void)
 {
-    return;
+	/* Nothing */
 }
 
 #endif /* USE_GTK1 */
