@@ -1,6 +1,4 @@
 /*
- * $Id: search_xml.c 19325 2011-07-07 12:48:24Z rmanfredi $
- *
  * Copyright (c) 2002-2003, Richard Eckart
  *
  *----------------------------------------------------------------------
@@ -35,8 +33,6 @@
 
 #include "gui.h"
 
-RCSID("$Id: search_xml.c 19325 2011-07-07 12:48:24Z rmanfredi $")
-
 #include "gtk-gnutella.h"
 
 #include "filter_core.h"
@@ -412,7 +408,7 @@ search_store_xml(void)
  * This is the new xml version. The searches are normally
  * retrieved from  ~/.gtk-gnutella/searches.xml.
  */
-gboolean
+G_GNUC_COLD gboolean
 search_retrieve_xml(void)
 {
     xnode_t *root, *xn;
