@@ -1,6 +1,4 @@
 /*
- * $Id: statusbar.c,v 1.7 2005/07/01 09:35:51 daichik Exp $
- *
  * Copyright (c) 2001-2003, Raphael Manfredi, Richard Eckart
  *
  *----------------------------------------------------------------------
@@ -37,12 +35,13 @@
 
 #include "gui.h"
 
-RCSID("$Id: statusbar.c,v 1.7 2005/07/01 09:35:51 daichik Exp $");
-
+#include "gtk-gnutella.h"
 #include "statusbar.h"
 
 #include "lib/glib-missing.h"
 #include "lib/misc.h"
+#include "lib/tm.h"
+
 #include "lib/override.h"	/* Must be the last header included */
 
 static const statusbar_msgid_t zero_msgid;
@@ -70,13 +69,13 @@ static guint scid_warn                = (guint) -1;
 /**
  * List with timeout entries for statusbar messages.
  */
-static GSList *sl_statusbar_timeouts = NULL;
+static GSList *sl_statusbar_timeouts;
 
 /*
  * Status bar
  */
-static gchar *statbar_botstr = NULL;
-static gchar *statbar_botstr_new = NULL;
+static gchar *statbar_botstr;
+static gchar *statbar_botstr_new;
 
 static void statusbar_gui_free_timeout(struct statusbar_timeout * t);
 static void statusbar_gui_free_timeout_list(void);
@@ -87,9 +86,9 @@ statusbar_get(void)
 {
     static GtkStatusbar *sb;
 
-	if (!sb)
-		sb = GTK_STATUSBAR(lookup_widget(main_window, "statusbar"));
-
+	if (!sb) {
+		sb = GTK_STATUSBAR(gui_main_window_lookup("statusbar"));
+	}
 	return sb;
 }
 
@@ -141,10 +140,10 @@ statusbar_gui_push(sb_types_t type, guint scid, guint timeout,
 	const gchar *format, ...)
 {
     va_list args;
-    statusbar_msgid_t id = zero_msgid;
+    statusbar_msgid_t id;
 
 	va_start(args, format);
-	statusbar_gui_push_v(type, scid, timeout, format, args);
+	id = statusbar_gui_push_v(type, scid, timeout, format, args);
     va_end(args);
 
     return id;
@@ -161,10 +160,10 @@ statusbar_msgid_t
 statusbar_gui_message(guint timeout, const gchar *format, ...)
 {
     va_list args;
-    statusbar_msgid_t id = zero_msgid;
+    statusbar_msgid_t id;
 
 	va_start(args, format);
-	statusbar_gui_push_v(SB_MESSAGE, scid_info, timeout, format, args);
+	id = statusbar_gui_push_v(SB_MESSAGE, scid_info, timeout, format, args);
     va_end(args);
 
     return id;
@@ -181,53 +180,15 @@ statusbar_msgid_t
 statusbar_gui_warning(guint timeout, const gchar *format, ...)
 {
     va_list args;
-    statusbar_msgid_t id = zero_msgid;
+    statusbar_msgid_t id;
 
 	va_start(args, format);
-	statusbar_gui_push_v(SB_WARNING, scid_warn, timeout, format, args);
+	id = statusbar_gui_push_v(SB_WARNING, scid_warn, timeout, format, args);
     va_end(args);
 
     return id;
 }
 
-void
-statusbar_gui_init(void)
-{
-    GtkStatusbar *sb;
-
-    sb = statusbar_get();
-
-    /* statusbar stuff */
-	scid_bottom = gtk_statusbar_get_context_id(sb, "default");
-	scid_hostsfile = gtk_statusbar_get_context_id(sb, "reading hosts file");
-	scid_queue_freezed = gtk_statusbar_get_context_id(sb, "queue freezed");
-   	scid_info = gtk_statusbar_get_context_id(sb, "information");
-    scid_ip_changed = gtk_statusbar_get_context_id(sb, "ip changed");
-    scid_warn = gtk_statusbar_get_context_id(sb, "warning");
-
-   	/*
-	 * This message lies at the bottom of the statusbar, and is never removed,
-	 * but to be replaced by an updated message.
-	 *
-	 * The current string held at the bottom is stored in `statbar_botstr'.
-	 * If a new string is pending replacement in `statbar_botstr_new', then
-	 * it will replace the current one when the last timeout for pushed
-	 * messages expires, at which time we'll know the bottom message is shown.
-	 *		--RAM, 27/06/2002
-	 */
-
-	statbar_botstr = g_strdup(GTA_WEBSITE);
-	statusbar_gui_push(SB_MESSAGE, scid_bottom, 0, "%s", statbar_botstr);
-}
-
-void
-statusbar_gui_shutdown(void)
-{
-    statusbar_gui_free_timeout_list();
-	G_FREE_NULL(statbar_botstr_new);
-	G_FREE_NULL(statbar_botstr);
-}
-
 void
 statusbar_gui_set_default(const char *format, ...)
 {
@@ -236,8 +197,7 @@ statusbar_gui_set_default(const char *format, ...)
 
     va_start(args, format);
 
-    if (statbar_botstr_new != NULL)
-        G_FREE_NULL(statbar_botstr_new);
+    G_FREE_NULL(statbar_botstr_new);
 
     if (format != NULL) {
         gm_vsnprintf(buf, sizeof(buf), format, args);
@@ -267,7 +227,7 @@ statusbar_gui_add_timeout(statusbar_msgid_t id, guint timeout)
     t = g_malloc0(sizeof *t);
 
 	t->id = id;
-	t->stamp = time(NULL);
+	t->stamp = tm_time();
 	t->timeout = timeout;
 
 	sl_statusbar_timeouts = g_slist_prepend(sl_statusbar_timeouts, t);
@@ -290,21 +250,22 @@ statusbar_gui_free_timeout(struct statusbar_timeout *t)
  * Check whether statusbar items have expired and remove them from the
  * statusbar.
  */
-void
+static void
 statusbar_gui_clear_timeouts(time_t now)
 {
 	GSList *sl, *to_remove = NULL;
 
 	for (sl = sl_statusbar_timeouts; sl; sl = g_slist_next(sl)) {
 		struct statusbar_timeout *t = sl->data;
+		const time_delta_t timeout = t->timeout;
 
-		if (delta_time(now, t->stamp) > t->timeout)
+		if (delta_time(now, t->stamp) > timeout)
 			to_remove = g_slist_prepend(to_remove, t);
 	}
 
-	for (sl = to_remove; sl; sl = g_slist_next(sl))
+	for (sl = to_remove; sl; sl = g_slist_next(sl)) {
 		statusbar_gui_free_timeout(sl->data);
-
+	}
 	g_slist_free(to_remove);
 
 	/*
@@ -335,4 +296,44 @@ statusbar_gui_free_timeout_list(void)
 	}
 }
 
+G_GNUC_COLD void
+statusbar_gui_init(void)
+{
+    GtkStatusbar *sb;
+
+    sb = statusbar_get();
+	statusbar_set_shadow_type(GTK_STATUSBAR(sb), GTK_SHADOW_ETCHED_IN);
+
+	scid_bottom = gtk_statusbar_get_context_id(sb, "default");
+	scid_hostsfile = gtk_statusbar_get_context_id(sb, "reading hosts file");
+	scid_queue_freezed = gtk_statusbar_get_context_id(sb, "queue freezed");
+   	scid_info = gtk_statusbar_get_context_id(sb, "information");
+    scid_ip_changed = gtk_statusbar_get_context_id(sb, "ip changed");
+    scid_warn = gtk_statusbar_get_context_id(sb, "warning");
+
+   	/*
+	 * This message lies at the bottom of the statusbar, and is never removed,
+	 * but to be replaced by an updated message.
+	 *
+	 * The current string held at the bottom is stored in `statbar_botstr'.
+	 * If a new string is pending replacement in `statbar_botstr_new', then
+	 * it will replace the current one when the last timeout for pushed
+	 * messages expires, at which time we'll know the bottom message is shown.
+	 *		--RAM, 27/06/2002
+	 */
+
+	statbar_botstr = g_strdup(GTA_WEBSITE);
+	statusbar_gui_push(SB_MESSAGE, scid_bottom, 0, "%s", statbar_botstr);
+
+	main_gui_add_timer(statusbar_gui_clear_timeouts);
+}
+
+void
+statusbar_gui_shutdown(void)
+{
+    statusbar_gui_free_timeout_list();
+	G_FREE_NULL(statbar_botstr_new);
+	G_FREE_NULL(statbar_botstr);
+}
+
 /* vi: set ts=4 sw=4 cindent: */
